# combineArrays
This package calculates weighted OWA functions and extending bivariate means" Functions are:
- owa: callback function if sorting is needed in general 
- weightedf: symmetric base aggregator 

## Documentation
[User Manual](https://github.com/nhenseler/wowa/blob/main/docs/wowa-theory.pdf)

## Installation
To install type:
```python
$ pip install wowa
```
## Usage of owa( x, w)
```python
from wowa import owa
```
Callback function if sorting is needed in general 
### Parameters
#### Input parameters:
Input parameters:
x[]: NumPy array of size n, float
w[]: NumPy array of size n, float
#### Output parameters:
double y: sum of x[i] * w[i] 

## Usage of weightedf( x, p, w, cb, L)
```python
from wowa import weightedf 
```
Symmetric base aggregator. The weights must add to one and be non-negative.
### Parameters
#### Input parameters:
x[]: NumPy array of inputs, size n, float
p[]: NumPy array of weights of inputs x[], size n, float
w[]: NumPy array of weights for OWA, size n, float
cb: callback function
L: number of binary tree levels. Run time = O[(n-1)L] 
#### Output parameters:
y = weightedf

## Test
To unit test type:
```python
$ test/test.py
```